/*
 * shohaku Copyright (C) 2005 tomoya nagatani
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package shohaku.ginkgo.nodes.core.base;

import java.util.Iterator;

import shohaku.ginkgo.Node;
import shohaku.ginkgo.nodes.AbstractValueNode;

/**
 * 文字列型のデータを表す値型のノードを提供します。 <br>
 * <br>
 * 値の生成規則： <br>
 * <code>value</code>属性が存在する場合は、属性値を値とします。 <br>
 * 値型の子エレメントが存在する場合は、全ての子エレメントの値を文字列として連結して値とします。 <br>
 * 値型の子エレメントが存在しない場合は、テキストノードを連結して値とします。 <br>
 * <br>
 */
public class StringNode extends AbstractValueNode {

    /**
     * 値を生成して返却します。
     * 
     * @return 生成された値
     */
    protected Object generateValue() {
        // value attribute
        String value = getAttribute("value");
        if (value == null) {
            StringBuffer buff = new StringBuffer();
            // elements
            for (Iterator i = getContext().valueElementIterator(); i.hasNext();) {
                buff.append(((Node) i.next()).getNodeValue());
            }
            if (buff.length() == 0) {
                // text node
                for (Iterator i = getContext().textIterator(); i.hasNext();) {
                    buff.append(((Node) i.next()).getNodeValue());
                }
                // text toString
                value = buff.toString().trim();
            } else {
                // text elements
                value = buff.toString();
            }
        }
        return value;
    }

}
